@@ -1,40 +1,36 @@
-( cd usr/X11R7/lib ; rm -rf libxcb-image.so.0 )
-( cd usr/X11R7/lib ; ln -sf libxcb-image.so.0.0.0 libxcb-image.so.0 )
-( cd usr/X11R7/lib ; rm -rf libxcb-property.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-property.so.1.0.0 libxcb-property.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-keysyms.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-keysyms.so.0.0.0 libxcb-keysyms.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-icccm.so.1 )
-( cd usr/X11R7/lib ; ln -sf libxcb-icccm.so.1.0.0 libxcb-icccm.so.1 )
-( cd usr/X11R7/lib ; rm -rf libxcb-render-util.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-render-util.so.0.0.0 libxcb-render-util.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-property.so.1 )
-( cd usr/X11R7/lib ; ln -sf libxcb-property.so.1.0.0 libxcb-property.so.1 )
-( cd usr/X11R7/lib ; rm -rf libxcb-aux.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-aux.so.0.0.0 libxcb-aux.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-reply.so.1 )
-( cd usr/X11R7/lib ; ln -sf libxcb-reply.so.1.0.0 libxcb-reply.so.1 )
-( cd usr/X11R7/lib ; rm -rf libxcb-wm.so.0 )
-( cd usr/X11R7/lib ; ln -sf libxcb-wm.so.0.0.0 libxcb-wm.so.0 )
 ( cd usr/X11R7/lib ; rm -rf libxcb-atom.so.1 )
 ( cd usr/X11R7/lib ; ln -sf libxcb-atom.so.1.0.0 libxcb-atom.so.1 )
-( cd usr/X11R7/lib ; rm -rf libxcb-reply.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-reply.so.1.0.0 libxcb-reply.so )
 ( cd usr/X11R7/lib ; rm -rf libxcb-atom.so )
 ( cd usr/X11R7/lib ; ln -sf libxcb-atom.so.1.0.0 libxcb-atom.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-render-util.so.0 )
-( cd usr/X11R7/lib ; ln -sf libxcb-render-util.so.0.0.0 libxcb-render-util.so.0 )
-( cd usr/X11R7/lib ; rm -rf libxcb-image.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-image.so.0.0.0 libxcb-image.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-icccm.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-icccm.so.1.0.0 libxcb-icccm.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-wm.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-wm.so.0.0.0 libxcb-wm.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-keysyms.so.0 )
-( cd usr/X11R7/lib ; ln -sf libxcb-keysyms.so.0.0.0 libxcb-keysyms.so.0 )
-( cd usr/X11R7/lib ; rm -rf libxcb-event.so )
-( cd usr/X11R7/lib ; ln -sf libxcb-event.so.1.0.0 libxcb-event.so )
-( cd usr/X11R7/lib ; rm -rf libxcb-event.so.1 )
-( cd usr/X11R7/lib ; ln -sf libxcb-event.so.1.0.0 libxcb-event.so.1 )
 ( cd usr/X11R7/lib ; rm -rf libxcb-aux.so.0 )
 ( cd usr/X11R7/lib ; ln -sf libxcb-aux.so.0.0.0 libxcb-aux.so.0 )
+( cd usr/X11R7/lib ; rm -rf libxcb-aux.so )
+( cd usr/X11R7/lib ; ln -sf libxcb-aux.so.0.0.0 libxcb-aux.so )
+( cd usr/X11R7/lib ; rm -rf libxcb-event.so.1 )
+( cd usr/X11R7/lib ; ln -sf libxcb-event.so.1.0.0 libxcb-event.so.1 )
+( cd usr/X11R7/lib ; rm -rf libxcb-event.so )
+( cd usr/X11R7/lib ; ln -sf libxcb-event.so.1.0.0 libxcb-event.so )
+( cd usr/X11R7/lib ; rm -rf libxcb-property.so.1 )
+( cd usr/X11R7/lib ; ln -sf libxcb-property.so.1.0.0 libxcb-property.so.1 )
+( cd usr/X11R7/lib ; rm -rf libxcb-property.so )
+( cd usr/X11R7/lib ; ln -sf libxcb-property.so.1.0.0 libxcb-property.so )
+( cd usr/X11R7/lib ; rm -rf libxcb-icccm.so.1 )
+( cd usr/X11R7/lib ; ln -sf libxcb-icccm.so.1.0.0 libxcb-icccm.so.1 )
+( cd usr/X11R7/lib ; rm -rf libxcb-icccm.so )
+( cd usr/X11R7/lib ; ln -sf libxcb-icccm.so.1.0.0 libxcb-icccm.so )
+( cd usr/X11R7/lib ; rm -rf libxcb-image.so.0 )
+( cd usr/X11R7/lib ; ln -sf libxcb-image.so.0.0.0 libxcb-image.so.0 )
+( cd usr/X11R7/lib ; rm -rf libxcb-image.so )
+( cd usr/X11R7/lib ; ln -sf libxcb-image.so.0.0.0 libxcb-image.so )
+( cd usr/X11R7/lib ; rm -rf libxcb-keysyms.so.1 )
+( cd usr/X11R7/lib ; ln -sf libxcb-keysyms.so.1.0.0 libxcb-keysyms.so.1 )
+( cd usr/X11R7/lib ; rm -rf libxcb-keysyms.so )
+( cd usr/X11R7/lib ; ln -sf libxcb-keysyms.so.1.0.0 libxcb-keysyms.so )
+( cd usr/X11R7/lib ; rm -rf libxcb-reply.so.1 )
+( cd usr/X11R7/lib ; ln -sf libxcb-reply.so.1.0.0 libxcb-reply.so.1 )
+( cd usr/X11R7/lib ; rm -rf libxcb-reply.so )
+( cd usr/X11R7/lib ; ln -sf libxcb-reply.so.1.0.0 libxcb-reply.so )
+( cd usr/X11R7/lib ; rm -rf libxcb-render-util.so.0 )
+( cd usr/X11R7/lib ; ln -sf libxcb-render-util.so.0.0.0 libxcb-render-util.so.0 )
+( cd usr/X11R7/lib ; rm -rf libxcb-render-util.so )
+( cd usr/X11R7/lib ; ln -sf libxcb-render-util.so.0.0.0 libxcb-render-util.so )
